=======
History
=======

0.1.2 (2021-05-18)
------------------

* The kinet2pcb() function will now generate a KiCad PCB file when given
  a netlist file name, a PyParsing object, or a SKiDL Circuit object.


0.1.1 (2019-03-09)
------------------

* Now runs under Python 2 & 3.


0.1.0 (2019-10-28)
------------------

* First release on PyPI.
